@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of ocrodjvu.
 #
@@ -122,10 +122,10 @@ class Zone(object):
 
 _xml_string_re = re.compile(
     u'''
-    ([^\x00-\x08\x0b\x0c\x0e-\x1f]*)
-    ( [\x00-\x08\x0b\x0c\x0e-\x1f]?)
+    ([^\x00-\x08\x0B\x0C\x0E-\x1F]*)
+    ( [\x00-\x08\x0B\x0C\x0E-\x1F]?)
     ''',
-    re.UNICODE | re.VERBOSE
+    re.VERBOSE
 )
 
 def set_text(element, text):
