@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of ocrodjvu.
 #
@@ -230,6 +230,8 @@ class ArgumentParser(cli.ArgumentParser):
     class list_engines(argparse.Action):
         def __call__(self, parser, namespace, values, option_string=None):
             for engine in parser.engines:
+                if engine.name[0] == '_':
+                    continue
                 try:
                     engine = engine()
                 except errors.EngineNotFound:
@@ -335,7 +337,7 @@ class ArgumentParser(cli.ArgumentParser):
             options.n_jobs = 1
         if options.n_jobs > 1 and not ipc.thread_safe:
             exc = Warning('the subprocess module is not thread-safe')
-            utils.enhance_import_error(exc, 'subprocess32', None, 'https://pypi.python.org/pypi/subprocess32')
+            utils.enhance_import_error(exc, 'subprocess32', None, 'https://pypi.org/project/subprocess32/')
             print('Warning: {exc}'.format(exc=exc), file=sys.stderr)
         return options
 
