@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of ocrodjvu.
 #
@@ -79,7 +79,7 @@ def _wait_for_worker(worker):
 def fix_html(s):
     '''
     Work around buggy hOCR output:
-    https://code.google.com/p/tesseract-ocr/issues/detail?id=376
+    https://groups.google.com/d/topic/tesseract-issues/AdZhdGFkTrA
     '''
     regex = re.compile(
         r'''
@@ -92,7 +92,7 @@ def fix_html(s):
         | &[#]x[0-9a-f]+;
         | [^<>&]+
         )
-        ''', re.IGNORECASE | re.VERBOSE | re.MULTILINE
+        ''', re.IGNORECASE | re.VERBOSE | re.DOTALL
     )
     return ''.join(
         chunk if n & 1 else cgi.escape(chunk)
@@ -226,7 +226,10 @@ class Engine(common.Engine):
 
     def recognize_hocr(self, image, language, details=text_zones.TEXT_DETAILS_WORD, uax29=None):
         language = self.user_to_tesseract(language)
-        character_details = details < text_zones.TEXT_DETAILS_WORD or (uax29 and details <= text_zones.TEXT_DETAILS_WORD)
+        character_details = (
+            details < text_zones.TEXT_DETAILS_WORD or
+            (uax29 and details <= text_zones.TEXT_DETAILS_WORD)
+        )
         with temporary.directory() as output_dir:
             tessconf_path = os.path.join(output_dir, 'tessconf')
             with open(tessconf_path, 'wt') as tessconf:
@@ -263,8 +266,13 @@ class Engine(common.Engine):
             with open(os.path.join(output_dir, hocr_path), 'r') as hocr_file:
                 contents = hocr_file.read()
             if character_details:
-                worker = ipc.Subprocess(
-                    [self.executable, image.name, os.path.join(output_dir, 'tmp'), '-l', language, 'makebox'] + self.extra_args,
+                worker = ipc.Subprocess([
+                        self.executable,
+                        image.name,
+                        os.path.join(output_dir, 'tmp'),
+                        '-l', language,
+                        'makebox'
+                    ] + self.extra_args,
                     stderr=ipc.PIPE,
                 )
                 _wait_for_worker(worker)
