@@ -2,14 +2,16 @@
 
 # Copyright © 2008-2016 Jakub Wilk <jwilk@jwilk.net>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of ocrodjvu.
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# ocrodjvu is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation.
+#
+# ocrodjvu is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+# for more details.
 
 '''
 Process hOCR documents.
@@ -141,16 +143,15 @@ def _apply_bboxes(djvu_class, bbox_source, text, settings, page_size):
             coordinates += [bbox]
     if len(coordinates) == len(text):
         pass  # OK
+    elif 0 < len(coordinates) - len(text) <= trailing_whitespace_len:
+        # Cuneiform ≥ 0.9 provides bounding boxes for some whitespace characters.
+        # Also, a newline character can appear at the end of line.
+        del coordinates[len(text):]
+    elif not settings.cuneiform and not embedded_eol and len(coordinates) == len(text) + 1:
+        # OCRopus produces weird hOCR output if line ends with a hyphen.
+        del coordinates[-1]
     else:
-        if 0 < len(coordinates) - len(text) <= trailing_whitespace_len:
-            # Cuneiform ≥ 0.9 provides bounding boxes for some whitespace characters.
-            # Also, a newline character can appear at the end of line.
-            del coordinates[len(text):]
-        elif not settings.cuneiform and not embedded_eol and len(coordinates) == len(text) + 1:
-            # OCRopus produces weird hOCR output if line ends with a hyphen.
-            del coordinates[-1]
-        else:
-            raise errors.MalformedHocr("number of bboxes doesn't match text length")
+        raise errors.MalformedHocr("number of bboxes doesn't match text length")
     assert len(coordinates) == len(text)
     if djvu_class > const.TEXT_ZONE_WORD:
         # Split words
@@ -422,7 +423,7 @@ def read_document(stream, settings):
         # Ideally, this should never be needed, but some OCR engines produce
         # such broken HTML:
         #  * https://bugs.launchpad.net/cuneiform-linux/+bug/585418
-        #  * https://code.google.com/p/tesseract-ocr/issues/detail?id=690
+        #  * https://groups.google.com/d/topic/tesseract-issues/NlYJA3GNDMI
         #
         # Moreover, the HTML parsers trip over such errors:
         #  * https://bugs.launchpad.net/lxml/+bug/690110
@@ -437,11 +438,10 @@ def read_document(stream, settings):
             root_element = etree.fromstring(contents, etree.HTMLParser(encoding='UTF-8'))
             return etree.ElementTree(root_element)
         del contents
+    elif settings.html5:
+        return html5_support.parse(stream)
     else:
-        if settings.html5:
-            return html5_support.parse(stream)
-        else:
-            return etree.parse(stream, etree.HTMLParser())
+        return etree.parse(stream, etree.HTMLParser())
 
 def extract_text(stream, **kwargs):
     '''
