@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of ocrodjvu.
 #
@@ -129,7 +129,7 @@ class BMP(ImageFormat):
         ))
         if self._pixel_format.bpp == 1:
             # palette:
-            file.write(struct.pack('<BBBB', 0xff, 0xff, 0xff, 0))
+            file.write(struct.pack('<BBBB', 0xFF, 0xFF, 0xFF, 0))
             file.write(struct.pack('<BBBB', 0, 0, 0, 0))
         file.write(data)
 
