@@ -2,14 +2,16 @@
 
 # Copyright © 2008-2016 Jakub Wilk <jwilk@jwilk.net>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of ocrodjvu.
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# ocrodjvu is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation.
+#
+# ocrodjvu is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+# for more details.
 
 '''interprocess communication'''
 
@@ -22,7 +24,7 @@ import signal
 thread_safe = True
 try:
     import subprocess32 as subprocess
-except ImportError:  # <no-coverage>
+except ImportError:  # no coverage
     import subprocess
     if os.name == 'posix':
         thread_safe = False
@@ -46,12 +48,12 @@ def get_signal_names():
     try:
         if data['SIGABRT'] == data['SIGIOT']:
             del data['SIGIOT']
-    except KeyError:  # <no-coverage>
+    except KeyError:  # no coverage
         pass
     try:
         if data['SIGCHLD'] == data['SIGCLD']:
             del data['SIGCLD']
-    except KeyError:  # <no-coverage>
+    except KeyError:  # no coverage
         pass
     return dict((no, name) for name, no in data.iteritems())
 
