@@ -2,31 +2,26 @@
 
 # Copyright © 2008-2016 Jakub Wilk <jwilk@jwilk.net>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of ocrodjvu.
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# ocrodjvu is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation.
+#
+# ocrodjvu is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+# for more details.
 
 from . import utils
 
 def get_icu():
     try:
-        # For PyICU ≥ 1.0
         import icu
+    except ImportError as ex:  # no coverage
+        utils.enhance_import_error(ex, 'PyICU', 'python-pyicu', 'https://pypi.org/project/PyICU/')
+    else:
         return icu
-    except ImportError:  # <no-coverage>
-        pass
-    try:  # <no-coverage>
-        # For PyICU < 1.0
-        import PyICU as icu
-        return icu
-    except ImportError as ex:  # <no-coverage>
-        utils.enhance_import_error(ex, 'PyICU', 'python-pyicu', 'https://pypi.python.org/pypi/PyICU/')
-        raise
 
 def simple_word_break_iterator(text):
     '''
