@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of ocrodjvu.
 #
@@ -94,6 +94,7 @@ class test_enhance_import():
         with interim(lib.utils, debian=True):
             t()
 
+# pylint: disable=eval-used
 class test_smart_repr():
 
     def test_byte_string(self):
@@ -115,9 +116,10 @@ class test_smart_repr():
             assert_equal(eval(s_repr), s)
         for s in 'jeż', '''j'e"ż''':
             s_repr = smart_repr(s, 'UTF-8')
-            assert_is_instance(s_repr, unicode)
-            assert_in(u'ż', s_repr)
-            assert_equal(eval(s_repr.encode('UTF-8')), s)
+            assert_is_instance(s_repr, str)
+            assert_in('ż', s_repr)
+            assert_equal(eval(s_repr), s)
+# pylint: enable=eval-used
 
 class test_parse_page_numbers():
 
@@ -150,10 +152,10 @@ class test_sanitize_utf8():
             warnings.showwarning = show
             t = sanitize_utf8(s).decode('UTF-8')
         assert_equal(t,
-            u'\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd'
-            u'\ufffd\t\n\ufffd\ufffd\r\ufffd\ufffd'
-            u'\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd'
-            u'\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd\ufffd'
+            u'\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD'
+            u'\uFFFD\t\n\uFFFD\uFFFD\r\uFFFD\uFFFD'
+            u'\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD'
+            u'\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD'
         )
 
     def test_ascii(self):
